/*****************************************************************************
 * Copyright (C) 2004
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/
using System;
using System.Management;
using System.Text.RegularExpressions;

namespace iOpener
{
	/// <summary>
	/// This class is used for registering events with the Windows Management Interface.  It's used in
	/// conjunction with the iOpener class to be notified that iTunes has been launched.
	/// </summary>
	public class WMIHandler
	{
		private iOpenerApplicationContext		context;		// the app context to call back to to fire up the COM interface when iTunes launches

		/// <summary>
		/// This constructor method just sets the context so we can refer back to the controller class (iOpener)
		/// </summary>
		/// <param name="context"></param>
		public WMIHandler(iOpenerApplicationContext context)
		{
			this.context = context;
		}

		/// <summary>
		/// This method is the handler that gets called by the WMI framework when iTunes gets launched.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		public void Started(object sender, EventArrivedEventArgs e)
		{
			ManagementBaseObject mbo = (ManagementBaseObject)e.NewEvent.Properties["TargetInstance"].Value;
			String executablePath = (String)mbo.Properties["ExecutablePath"].Value;
			Regex r = new Regex("iTunes.exe");
			Match m = r.Match(executablePath);
			if (m.Success) context.InitializeItunesApp();
		}
	}
}
